@@ -50,7 +50,8 @@ PCAproj <- function (x, k = 2, method = c ("mad", "sd", "qn"), CalcMethod = c("e
 		if (nmax > n)
 		{
 			aux = matrix (runif ((nmax-n) * n), nrow = nmax-n)
-			y = rbind (y, t(t(aux %*% as.matrix(x)) - DataObj$center))
+			y = rbind (y, t(t(aux %*% x) - DataObj$center))
+			##y = rbind (y, aux %*% y) ## use this instead?
 		}
 	}
 	else if (CalcMethod == "sphere")
@@ -93,3 +94,58 @@ PCAproj <- function (x, k = 2, method = c ("mad", "sd", "qn"), CalcMethod = c("e
 	else
 		.DataPostProc (DataObj, ret.C$lambda, veig, NULL, match.call(), scores)
 }
+
+
+.DataPostProc <- function (DataObj, obj, loadings, scores, cl, bScores)
+{
+	idx <- order (obj, decreasing = TRUE)
+	obj <- obj [idx]
+	loadings <- loadings [,idx, drop = FALSE]
+
+	if (bScores)
+		scores <- scores [,idx, drop = FALSE]
+
+	ret <- list()
+
+   ##loadings
+	{
+		c <- ncol (loadings)
+		r <- nrow (loadings)
+		ret$loadings <- loadings
+
+		ret$loadings <- .loadSgnU (ret$loadings)
+
+		if (is.null (dimnames (DataObj$x)[[2]]))
+			dimnames (ret$loadings) <- list (paste (rep ("V", r), 1:r, sep = ""), paste (rep ("Comp.", c), 1:c, sep = ""))
+		else
+			dimnames (ret$loadings) <- list (dimnames (DataObj$x)[[2]], paste (rep ("Comp.", c), 1:c, sep = ""))
+
+		class (ret$loadings) <- "loadings"
+	}
+
+   ##sdev
+	ret$sdev <- as.numeric (obj)
+	names (ret$sdev) <- dimnames (ret$loadings)[[2]]
+
+   ##center
+	ret$center <- DataObj$center
+   ##scale
+	ret$scale <- DataObj$scale
+   ##n.obs
+	ret$n.obs <- nrow (DataObj$x)
+
+   ##scores
+	if (bScores)
+	{
+		ret$scores <- scores
+		dimnames (ret$scores) <- list (1:nrow (scores), dimnames (ret$loadings)[[2]]) ;
+	}
+	else
+		ret$scores <- NULL
+
+	ret$call <- cl
+
+	class (ret) <- c ("pcaPP", "princomp")
+	return (ret)
+}
+
